==> haskell-sbv-7.12-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sbv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sbv
version: 7.12
id: sbv-7.12-5Ax5oslmL9GIEW8uEOu5Mc
key: sbv-7.12-5Ax5oslmL9GIEW8uEOu5Mc
license: BSD-3-Clause
copyright: Levent Erkok, 2010-2018
maintainer: Levent Erkok (erkokl@gmail.com)
author: Levent Erkok
stability: Experimental
homepage: http://leventerkok.github.com/sbv/
synopsis: SMT Based Verification: Symbolic Haskell theorem prover using SMT solving.
description:
    Express properties about Haskell programs and automatically prove them using SMT
    (Satisfiability Modulo Theories) solvers.
    .
    For details, please see: <http://leventerkok.github.com/sbv/>
category: Formal Methods, Theorem Provers, Bit vectors, Symbolic Computation, Math, SMT
abi: ef49773ec32c1adf85426eb6913a6242
exposed: True
exposed-modules:
    Data.SBV Data.SBV.Char Data.SBV.Control Data.SBV.Dynamic
    Data.SBV.Internals Data.SBV.List Data.SBV.List.Bounded
    Data.SBV.RegExp Data.SBV.String Data.SBV.Tools.CodeGen
    Data.SBV.Tools.GenTest Data.SBV.Tools.Overflow
    Data.SBV.Tools.Polynomial Data.SBV.Tools.STree
    Documentation.SBV.Examples.BitPrecise.BitTricks
    Documentation.SBV.Examples.BitPrecise.BrokenSearch
    Documentation.SBV.Examples.BitPrecise.Legato
    Documentation.SBV.Examples.BitPrecise.MergeSort
    Documentation.SBV.Examples.BitPrecise.MultMask
    Documentation.SBV.Examples.BitPrecise.PrefixSum
    Documentation.SBV.Examples.CodeGeneration.AddSub
    Documentation.SBV.Examples.CodeGeneration.CRC_USB5
    Documentation.SBV.Examples.CodeGeneration.Fibonacci
    Documentation.SBV.Examples.CodeGeneration.GCD
    Documentation.SBV.Examples.CodeGeneration.PopulationCount
    Documentation.SBV.Examples.CodeGeneration.Uninterpreted
    Documentation.SBV.Examples.Crypto.AES
    Documentation.SBV.Examples.Crypto.RC4
    Documentation.SBV.Examples.Existentials.CRCPolynomial
    Documentation.SBV.Examples.Existentials.Diophantine
    Documentation.SBV.Examples.Lists.BoundedMutex
    Documentation.SBV.Examples.Lists.Fibonacci
    Documentation.SBV.Examples.Lists.Nested
    Documentation.SBV.Examples.Misc.Auxiliary
    Documentation.SBV.Examples.Misc.Enumerate
    Documentation.SBV.Examples.Misc.Floating
    Documentation.SBV.Examples.Misc.ModelExtract
    Documentation.SBV.Examples.Misc.NoDiv0
    Documentation.SBV.Examples.Misc.Polynomials
    Documentation.SBV.Examples.Misc.SoftConstrain
    Documentation.SBV.Examples.Misc.Word4
    Documentation.SBV.Examples.Optimization.ExtField
    Documentation.SBV.Examples.Optimization.LinearOpt
    Documentation.SBV.Examples.Optimization.Production
    Documentation.SBV.Examples.Optimization.VM
    Documentation.SBV.Examples.Puzzles.Birthday
    Documentation.SBV.Examples.Puzzles.Coins
    Documentation.SBV.Examples.Puzzles.Counts
    Documentation.SBV.Examples.Puzzles.DogCatMouse
    Documentation.SBV.Examples.Puzzles.Euler185
    Documentation.SBV.Examples.Puzzles.Fish
    Documentation.SBV.Examples.Puzzles.HexPuzzle
    Documentation.SBV.Examples.Puzzles.MagicSquare
    Documentation.SBV.Examples.Puzzles.NQueens
    Documentation.SBV.Examples.Puzzles.SendMoreMoney
    Documentation.SBV.Examples.Puzzles.Sudoku
    Documentation.SBV.Examples.Puzzles.U2Bridge
    Documentation.SBV.Examples.Queries.AllSat
    Documentation.SBV.Examples.Queries.CaseSplit
    Documentation.SBV.Examples.Queries.Enums
    Documentation.SBV.Examples.Queries.FourFours
    Documentation.SBV.Examples.Queries.GuessNumber
    Documentation.SBV.Examples.Queries.Interpolants
    Documentation.SBV.Examples.Queries.UnsatCore
    Documentation.SBV.Examples.Strings.RegexCrossword
    Documentation.SBV.Examples.Strings.SQLInjection
    Documentation.SBV.Examples.Uninterpreted.AUF
    Documentation.SBV.Examples.Uninterpreted.Deduce
    Documentation.SBV.Examples.Uninterpreted.Function
    Documentation.SBV.Examples.Uninterpreted.Shannon
    Documentation.SBV.Examples.Uninterpreted.Sort
    Documentation.SBV.Examples.Uninterpreted.UISortAllSat
hidden-modules: Data.SBV.Core.AlgReals Data.SBV.Core.Concrete
                Data.SBV.Core.Data Data.SBV.Core.Kind Data.SBV.Core.Model
                Data.SBV.Core.Operations Data.SBV.Core.Floating
                Data.SBV.Core.Splittable Data.SBV.Core.Symbolic
                Data.SBV.Control.Query Data.SBV.Control.Types
                Data.SBV.Control.Utils Data.SBV.Compilers.C
                Data.SBV.Compilers.CodeGen Data.SBV.SMT.SMT Data.SBV.SMT.SMTLib
                Data.SBV.SMT.SMTLib2 Data.SBV.SMT.SMTLibNames Data.SBV.SMT.Utils
                Data.SBV.Provers.Prover Data.SBV.Provers.Boolector
                Data.SBV.Provers.CVC4 Data.SBV.Provers.Yices Data.SBV.Provers.Z3
                Data.SBV.Provers.MathSAT Data.SBV.Provers.ABC
                Data.SBV.Utils.Boolean Data.SBV.Utils.Numeric Data.SBV.Utils.TDiff
                Data.SBV.Utils.Lib Data.SBV.Utils.PrettyNum Data.SBV.Utils.SExpr
import-dirs: /usr/lib/ghc-8.6.2/site-local/sbv-7.12
library-dirs: /usr/lib/ghc-8.6.2/site-local/sbv-7.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/sbv-7.12
hs-libraries: HSsbv-7.12-5Ax5oslmL9GIEW8uEOu5Mc
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc array-0.5.3.0
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 containers-0.6.0.1
    crackNum-2.3-4LTaUC4c15AIrmPgUx7QnW deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    generic-deriving-1.12.2-6sFUoEtoTtTA6qagsJUL6M ghc-8.6.2 mtl-2.2.2
    pretty-1.1.3.6 process-1.6.3.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    reinterpret-cast-0.1.0-A055EXyz5VKHfSQafAOqhM
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-sbv/html/sbv.haddock
haddock-html: /usr/share/doc/haskell-sbv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sbv-7.12-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sbv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sbv
version: 7.12
id: sbv-7.12-KLKvlRR5MXLAEBfpGELdl
key: sbv-7.12-KLKvlRR5MXLAEBfpGELdl
license: BSD-3-Clause
copyright: Levent Erkok, 2010-2018
maintainer: Levent Erkok (erkokl@gmail.com)
author: Levent Erkok
stability: Experimental
homepage: http://leventerkok.github.com/sbv/
synopsis: SMT Based Verification: Symbolic Haskell theorem prover using SMT solving.
description:
    Express properties about Haskell programs and automatically prove them using SMT
    (Satisfiability Modulo Theories) solvers.
    .
    For details, please see: <http://leventerkok.github.com/sbv/>
category: Formal Methods, Theorem Provers, Bit vectors, Symbolic Computation, Math, SMT
abi: df852cb749d1f95e6e36f7be84e30f99
exposed: True
exposed-modules:
    Data.SBV Data.SBV.Char Data.SBV.Control Data.SBV.Dynamic
    Data.SBV.Internals Data.SBV.List Data.SBV.List.Bounded
    Data.SBV.RegExp Data.SBV.String Data.SBV.Tools.CodeGen
    Data.SBV.Tools.GenTest Data.SBV.Tools.Overflow
    Data.SBV.Tools.Polynomial Data.SBV.Tools.STree
    Documentation.SBV.Examples.BitPrecise.BitTricks
    Documentation.SBV.Examples.BitPrecise.BrokenSearch
    Documentation.SBV.Examples.BitPrecise.Legato
    Documentation.SBV.Examples.BitPrecise.MergeSort
    Documentation.SBV.Examples.BitPrecise.MultMask
    Documentation.SBV.Examples.BitPrecise.PrefixSum
    Documentation.SBV.Examples.CodeGeneration.AddSub
    Documentation.SBV.Examples.CodeGeneration.CRC_USB5
    Documentation.SBV.Examples.CodeGeneration.Fibonacci
    Documentation.SBV.Examples.CodeGeneration.GCD
    Documentation.SBV.Examples.CodeGeneration.PopulationCount
    Documentation.SBV.Examples.CodeGeneration.Uninterpreted
    Documentation.SBV.Examples.Crypto.AES
    Documentation.SBV.Examples.Crypto.RC4
    Documentation.SBV.Examples.Existentials.CRCPolynomial
    Documentation.SBV.Examples.Existentials.Diophantine
    Documentation.SBV.Examples.Lists.BoundedMutex
    Documentation.SBV.Examples.Lists.Fibonacci
    Documentation.SBV.Examples.Lists.Nested
    Documentation.SBV.Examples.Misc.Auxiliary
    Documentation.SBV.Examples.Misc.Enumerate
    Documentation.SBV.Examples.Misc.Floating
    Documentation.SBV.Examples.Misc.ModelExtract
    Documentation.SBV.Examples.Misc.NoDiv0
    Documentation.SBV.Examples.Misc.Polynomials
    Documentation.SBV.Examples.Misc.SoftConstrain
    Documentation.SBV.Examples.Misc.Word4
    Documentation.SBV.Examples.Optimization.ExtField
    Documentation.SBV.Examples.Optimization.LinearOpt
    Documentation.SBV.Examples.Optimization.Production
    Documentation.SBV.Examples.Optimization.VM
    Documentation.SBV.Examples.Puzzles.Birthday
    Documentation.SBV.Examples.Puzzles.Coins
    Documentation.SBV.Examples.Puzzles.Counts
    Documentation.SBV.Examples.Puzzles.DogCatMouse
    Documentation.SBV.Examples.Puzzles.Euler185
    Documentation.SBV.Examples.Puzzles.Fish
    Documentation.SBV.Examples.Puzzles.HexPuzzle
    Documentation.SBV.Examples.Puzzles.MagicSquare
    Documentation.SBV.Examples.Puzzles.NQueens
    Documentation.SBV.Examples.Puzzles.SendMoreMoney
    Documentation.SBV.Examples.Puzzles.Sudoku
    Documentation.SBV.Examples.Puzzles.U2Bridge
    Documentation.SBV.Examples.Queries.AllSat
    Documentation.SBV.Examples.Queries.CaseSplit
    Documentation.SBV.Examples.Queries.Enums
    Documentation.SBV.Examples.Queries.FourFours
    Documentation.SBV.Examples.Queries.GuessNumber
    Documentation.SBV.Examples.Queries.Interpolants
    Documentation.SBV.Examples.Queries.UnsatCore
    Documentation.SBV.Examples.Strings.RegexCrossword
    Documentation.SBV.Examples.Strings.SQLInjection
    Documentation.SBV.Examples.Uninterpreted.AUF
    Documentation.SBV.Examples.Uninterpreted.Deduce
    Documentation.SBV.Examples.Uninterpreted.Function
    Documentation.SBV.Examples.Uninterpreted.Shannon
    Documentation.SBV.Examples.Uninterpreted.Sort
    Documentation.SBV.Examples.Uninterpreted.UISortAllSat
hidden-modules: Data.SBV.Core.AlgReals Data.SBV.Core.Concrete
                Data.SBV.Core.Data Data.SBV.Core.Kind Data.SBV.Core.Model
                Data.SBV.Core.Operations Data.SBV.Core.Floating
                Data.SBV.Core.Splittable Data.SBV.Core.Symbolic
                Data.SBV.Control.Query Data.SBV.Control.Types
                Data.SBV.Control.Utils Data.SBV.Compilers.C
                Data.SBV.Compilers.CodeGen Data.SBV.SMT.SMT Data.SBV.SMT.SMTLib
                Data.SBV.SMT.SMTLib2 Data.SBV.SMT.SMTLibNames Data.SBV.SMT.Utils
                Data.SBV.Provers.Prover Data.SBV.Provers.Boolector
                Data.SBV.Provers.CVC4 Data.SBV.Provers.Yices Data.SBV.Provers.Z3
                Data.SBV.Provers.MathSAT Data.SBV.Provers.ABC
                Data.SBV.Utils.Boolean Data.SBV.Utils.Numeric Data.SBV.Utils.TDiff
                Data.SBV.Utils.Lib Data.SBV.Utils.PrettyNum Data.SBV.Utils.SExpr
import-dirs: /usr/lib/ghc-8.6.3/site-local/sbv-7.12
library-dirs: /usr/lib/ghc-8.6.3/site-local/sbv-7.12
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/sbv-7.12
hs-libraries: HSsbv-7.12-KLKvlRR5MXLAEBfpGELdl
depends:
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc array-0.5.3.0
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 containers-0.6.0.1
    crackNum-2.3-4LTaUC4c15AIrmPgUx7QnW deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1
    generic-deriving-1.12.2-63rdjMxmrbKG8DJ9MhNvPL ghc-8.6.3 mtl-2.2.2
    pretty-1.1.3.6 process-1.6.3.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    reinterpret-cast-0.1.0-7LcxVTKX7KGIjFms7mMZTW
    syb-0.7-KRW1LCxdMiCJrmhxCvzo37 template-haskell-2.14.0.0
    time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-sbv/html/sbv.haddock
haddock-html: /usr/share/doc/haskell-sbv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
